<?php //  -----------------------------------------------------------------  //
//  Projekt: eBiene mySQL-Backup 0.7                                         //
//  Download: http://lab.eBiene.de                                           //
//  Autor: Sergej Mueller                                                    //
//                                                                           //
//  Dateiname: require/backup.class.php                                      //
//  Bearbeitungsdatum: 16. Februar 2004                                      //
//  -----------------------------------------------------------------------  //

class backup_global_class {
  
  
  /**
  * get_mysql_tables
  *
  * Liefert alle Tabellen einer Datenbank
  *
  * @package  eBiene mySQL-Backup 0.7
  * @author   Sergej Mueller
  * @since    16.02.2004
  * @access		private
  * @return   arrayn  $tables_array  Array mit allen Tabellen
  */
  
  function get_mysql_tables() {
	  // Verbindung herstellen
	  $GLOBALS['mysql_class']->check_mysql_connection();
	  
	  // Tabellen auslesen
	  if (!$mysql_tables = $GLOBALS['mysql_class']->get_fetch_array('SHOW TABLES FROM ' .MYSQL_DATABASE)) {
	    $this->cache_error_messages('Keine Tabellen in der Datenbank vorhanden!');
	    return false;
	  }
	  
	  // Feldnamen & Datensaetze zaehlen
	  foreach ($mysql_tables as $key => $mysql_table) {
	    $tables_array[$key]['table_name'] = $mysql_table[0];
	    
	    if (!$table_fields = $GLOBALS['mysql_class']->get_fetch_row('SHOW COLUMNS FROM ' .$mysql_table[0])) {
		    $this->cache_error_messages('Feldnamen konnten leider nicht ausgelesen werden!');
	      return false;
	    }
	    
	    if (!$data_counter = $GLOBALS['mysql_class']->get_fetch_row('SELECT COUNT(' .$table_fields[0]. ') FROM ' .$mysql_table[0])) {
		    $this->cache_error_messages('Datens&auml;tze konnten leider nicht gez&auml;hlt werden!');
	      return false;
	    }
      
	    $tables_array[$key]['data_counter'] = $data_counter[0];
	  }
	  
	  // Verbindung trennen
	  $GLOBALS['mysql_class']->close_mysql_connection();
	  
	  return $tables_array;
  }
  
  
  /**
  * get_file_exists
  *
  * Prueft Backup-Datei auf Existenz
  *
  * @package  eBiene mySQL-Backup 0.7
  * @author   Sergej Mueller
  * @since    16.02.2004
  * @access		private
  * @param    string   $file_name  Name der Datei
  * @return   boolean  true/false  TRUE bei Erfolg, FALSE bei Fehlern
  */
  
  function get_file_exists($file_name) {
    if (!defined('BACKUP_FILES_ROOT')) {
	    return false;
	  }
    if (!file_exists(BACKUP_FILES_ROOT)) {
	    return false;
	  }
	  if (file_exists(BACKUP_FILES_ROOT . $file_name)) {
	    return true;
	  } else {
	    return false;
	  }
  }
  
  
  /**
  * get_version_control
  *
  * Auf neue eBiene mySQL-Backup-Version prfen
  *
  * @package  eBiene mySQL-Backup 0.7
  * @author   Sergej Mueller
  * @since    16.02.2004
  * @access		private
  * @return   boolean  true/false  TRUE bei Erfolg, FALSE bei Fehlern
  */
  
  function get_version_control() {
    // Pfad zur Versionsdatei
	  $version_file_path = 'http://lab.ebiene.de/download/mysql_backup/latest_version.txt';
	  
	  // Versionsdatei oeffnen
    if (!$handle = fopen($version_file_path, "r")) {
	    $this->cache_error_messages('Datei mit Update-Informationen konnte nicht ge&ouml;ffnet werden!');
      return false;
	  }
	  
	  // Versionsdatei auslesen
	  $latest_version = fgets($handle, 10);
	  
	  // Versionsdatei schliessen
	  if (!fclose($handle)) {
	    $this->cache_error_messages('Datei mit Update-Informationen konnte nicht geschlossen werden!');
      return false;
	  }
	  
	  // Versionen vergleichen
	  if (strcmp($latest_version, MYSQL_BACKUP_VERSION) > 0) {
	    $this->cache_error_messages('<a href="http://lab.eBiene.de" target="_blank">Neue Version "' .$latest_version. '" ist auf dem Download-Server vorhanden!</a><br>&middot; Bitte f&uuml;hren Sie ein Upgrade durch.');
      return true;
	  } else {
	    $this->cache_error_messages('Ihre Applikation ist auf dem aktuellsten Stand!', 'done');
      return false;
	  }
  }
  
  
  /**
  * cache_error_messages
  *
  * Meldungen aufbewahren
  *
  * @package  eBiene mySQL-Backup 0.7
  * @author   Sergej Mueller
  * @since    16.02.2004
  * @access		private
  * @param    string  $message_string  Fehlermeldung als Plain-Text
  * @param    string  $message_type    Typ der Meldung [optional]
  */
  
  function cache_error_messages($message_string, $message_type = 'error') {
	  if (!isset($GLOBALS['internal_messages']) OR !is_array($GLOBALS['internal_messages'])) {
	    $GLOBALS['internal_messages'] = array();
	  }
    
    array_push($GLOBALS['internal_messages'], array(
	                                                  'string' => $message_string,
                                                    'style' => $message_type
                                                   )
              );
  }
  
  
  /**
  * get_global_microtime
  *
  * Sekunden ermitteln
  *
  * @package  eBiene mySQL-Backup 0.7
  * @author   Sergej Mueller
  * @since    16.02.2004
  * @access		private
  * @return   int  Microtime in Mikrosekunden
  */
  
  function get_global_microtime() {
    list($sec, $msec) = split(' ', microtime());
    return ((float)$sec + (float)$msec);
  }
  
  
  /**
  * get_global_endtime
  *
  * Zeit-Differenz ermitteln
  *
  * @package  eBiene mySQL-Backup 0.7
  * @author   Sergej Mueller
  * @since    16.02.2004
  * @access		private
  * @return   double  Zeit-Differenz
  */
  
  function get_global_endtime() {
    return number_format(($this->get_global_microtime() - BACKUP_START_TIME), 2,".", ",");
  }
}
?>